@@ -186,7 +186,7 @@ COUNTRIES = (
     ('RU', _(u'Russian Federation')),
     ('RW', _(u'Rwanda')),
     ('BL', _(u'Saint Barth\xe9lemy')),
-    ('SH', _(u'Saint Helena')),
+    ('SH', _(u'Saint Helena, Ascension and Tristan Da Cunha')),
     ('KN', _(u'Saint Kitts and Nevis')),
     ('LC', _(u'Saint Lucia')),
     ('MF', _(u'Saint Martin')),
@@ -242,7 +242,7 @@ COUNTRIES = (
     ('VE', _(u'Venezuela, Bolivarian Republic of')),
     ('VN', _(u'Viet Nam')),
     ('VG', _(u'Virgin Islands, British')),
-    ('VI', _(u'Virgin Islands, U.s.')),
+    ('VI', _(u'Virgin Islands, U.S.')),
     ('WF', _(u'Wallis and Futuna')),
     ('EH', _(u'Western Sahara')),
     ('YE', _(u'Yemen')),
@@ -266,6 +266,7 @@ COUNTRIES_PLUS = (
     ('AR', _(u'Argentina')),
     ('AM', _(u'Armenia')),
     ('AW', _(u'Aruba')),
+    ('SH', _(u'Ascension and Tristan Da Cunha Saint Helena')),
     ('AU', _(u'Australia')),
     ('AT', _(u'Austria')),
     ('AZ', _(u'Azerbaijan')),
@@ -447,7 +448,7 @@ COUNTRIES_PLUS = (
     ('RU', _(u'Russian Federation')),
     ('RW', _(u'Rwanda')),
     ('BL', _(u'Saint Barth\xe9lemy')),
-    ('SH', _(u'Saint Helena')),
+    ('SH', _(u'Saint Helena, Ascension and Tristan Da Cunha')),
     ('KN', _(u'Saint Kitts and Nevis')),
     ('LC', _(u'Saint Lucia')),
     ('MF', _(u'Saint Martin')),
@@ -493,7 +494,7 @@ COUNTRIES_PLUS = (
     ('TM', _(u'Turkmenistan')),
     ('TC', _(u'Turks and Caicos Islands')),
     ('TV', _(u'Tuvalu')),
-    ('VI', _(u'U.s. Virgin Islands')),
+    ('VI', _(u'U.S. Virgin Islands')),
     ('UG', _(u'Uganda')),
     ('UA', _(u'Ukraine')),
     ('AE', _(u'United Arab Emirates')),
@@ -507,7 +508,7 @@ COUNTRIES_PLUS = (
     ('VE', _(u'Venezuela, Bolivarian Republic of')),
     ('VN', _(u'Viet Nam')),
     ('VG', _(u'Virgin Islands, British')),
-    ('VI', _(u'Virgin Islands, U.s.')),
+    ('VI', _(u'Virgin Islands, U.S.')),
     ('WF', _(u'Wallis and Futuna')),
     ('EH', _(u'Western Sahara')),
     ('YE', _(u'Yemen')),
@@ -701,7 +702,7 @@ OFFICIAL_COUNTRIES = {
     'RU': u'RUSSIAN FEDERATION',
     'RW': u'RWANDA',
     'BL': u'SAINT BARTH\xc9LEMY',
-    'SH': u'SAINT HELENA',
+    'SH': u'SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA',
     'KN': u'SAINT KITTS AND NEVIS',
     'LC': u'SAINT LUCIA',
     'MF': u'SAINT MARTIN',
